@@ -101,6 +101,7 @@ class Console:
             stream.write(message)
             endl = kwargs.pop('endl', self._endl)
             stream.write(endl)
+            stream.flush()
 
     def log(self, message: str, **kwargs: Any) -> None:
         self._print(self._stdout, message, **kwargs)
@@ -187,3 +188,5 @@ def _init_console() -> None:
         setattr(Console, color, partialmethod(Console.style, fg=color))
 
     setattr(Console, '_init', True)
+
+_init_console()
